@@ -1,20 +1,21 @@
 #' Predict conditional probabilities
 #'
 #' @description The function \code{predict.qad()} can be utilized to predict the probabilities of the event that Y lies in
-#' specific intervals given X=x, or vice versa. Additionally, the mass of the conditional distribution functions are plotted.
+#' specific intervals given X=x, or vice versa. Thereby, the intervals are calculated as retransformed intervals (by using the empirical quantil function) defining the checkerboard grid. Additionally, the mass of the conditional distribution functions are plotted.
 #' The prediction can be computed in the sample setting as well as in the copula setting (pseudo-observation in the unit square).
 #'
 #' @param object an object of class 'qad', which determines the underlying checkerboard aggregation.
 #' @param values a vector containing the x or the y values for which the conditional probabilities should be predicted.
 #' @param conditioned a character specifying on which variable is conditioned. Options are "x1" (default) or "x2".
 #' @param nr_intervals an integer, which determines a different number of intervals for the prediction (only possible in the copula setting).
-#' @param copula a logical (default =FALSE) determining whether the empirical checkerboard copula is used or the retransformed data.
-#' @param prediction_interval a vector specifying the interval boundaries for which the conditional probability is computed. Options are NULL (default) to predict the conditional probabilites for all intervals or a vector c(lower_boundary, upper_boundary) indicating the boundaries.
-#' @param pred_plot a logical indicating if the conditional probabilites are plotted.
+#' @param copula a logical (default = FALSE) determining whether the empirical checkerboard copula is used or the retransformed data.
+#' @param prediction_interval a vector specifying the interval boundaries for which the conditional probability is computed. Options are NULL (default) to predict the conditional probabilities for all intervals or a vector c(lower boundary, upper boundary) indicating the boundaries.
+#' @param pred_plot a logical indicating if the conditional probabilities are plotted.
 #' @param panel.grid a logical indicating whether the panel.grid is plotted.
 #' @param ... some methods for this generic require additional arguments.  None are used in this method.
 #'
-#' @return a list containing a data.frame with the interval boundaries and the prediction probabilities and a plot depicting the mass of the conditional distributions functions.
+#' @return a list containing a data.frame with the computed intervals (lower and upper boundaries) and the prediction probabilities (i.e., the probability that Y lies in the interval Ii given X = x).
+#' Furthermore, a heatmap depicting the mass of the conditional distribution functions is returned.
 #'
 #' @note Predictions are only possible for values within the range of the sample (or between 0 and 1 in the copula setting). For given values exceeding the range NA is returned.
 #'
@@ -145,9 +146,9 @@ predict.qad <- function(object,
   print_prob <- data.frame(t(pred_prob[,4:NCOL(pred_prob)]))
   names(print_prob) <- pred_prob$Interval
   row.names(print_prob) <- names(pred_prob)[-c(1:3)]
-  cat("Intervall definition:\n")
+  cat(paste0("Intervalls for the variable ", setdiff(c("x1", "x2"), conditioned)," \n"))
   print.data.frame(pred_prob[,1:3])
-  cat("\nPrediction probabilities:\n")
+  cat(paste0("\nProbability that ",toupper(setdiff(c("x1", "x2"), conditioned))," given ",toupper(conditioned),"=",conditioned," lies in the interval I_i :\n"))
   print.data.frame(print_prob)
 
   if(pred_plot){
